@@ -189,12 +189,8 @@ def get_invoker_level(invoker_name):
     # check how much TOKEN the invoker has
     wallet_token_info = Wallet(invoker_name).get_token(TOKEN_NAME)
 
-    if not wallet_token_info:
-        invoker_delegationsIn + invoker_stake == 0
-    else:
-        invoker_delegationsIn = float(wallet_token_info['delegationsIn'])
-        invoker_stake = float(wallet_token_info['stake'])
-
+    invoker_delegationsIn = float(wallet_token_info['delegationsIn'])
+    invoker_stake = float(wallet_token_info['stake'])
 
     # does invoker meet level 4 requirements?
     min_staked = float(config['AccessLevel4']['MIN_TOKEN_STAKED'])
@@ -220,7 +216,8 @@ def get_invoker_level(invoker_name):
     if invoker_delegationsIn + invoker_stake >= min_staked:
         return 1
 
-    return 0
+    else:
+        return 0
 
 
 def is_block_listed(name):
